@@ -8,7 +8,7 @@ use Storable;
 ############################################################################
 package Net::OpenID::Consumer;
 BEGIN {
-  $Net::OpenID::Consumer::VERSION = '1.030099_003';
+  $Net::OpenID::Consumer::VERSION = '1.030099_004';
 }
 
 use fields (
@@ -163,15 +163,24 @@ sub _fail {
     my ($code, $text) = @_;
 
     $text ||= {
-        'no_identity_server' => "The provided URL doesn't declare its OpenID identity server.",
-        'empty_url' => "No URL entered.",
-        'bogus_url' => "Invalid URL.",
-        'no_head_tag' => "URL provided doesn't seem to have a head tag.",
-        'url_fetch_err' => "Error fetching the provided URL.",
-        'bad_mode' => "The openid.mode argument is not correct",
-        'protocol_version_incorrect' => "The provided URL uses the wrong protocol version",
-        'naive_verify_failed_return' => "Provider says signature is invalid",
+        'bad_mode'                    => "The openid.mode argument is not correct",
+        'bogus_return_to'             => "The provided return URL doesn't match required_root.",
+        'bogus_url'                   => "Invalid URL.",
+        'empty_url'                   => "No URL entered.",
+        'expired_association'         => "Association between Provider and Relying Pary has expired.",
         'naive_verify_failed_network' => "Could not contact provider to verify signature",
+        'naive_verify_failed_return'  => "Provider says signature is invalid",
+        'no_head_tag'                 => "URL provided doesn't seem to have a head tag.",
+        'no_identity'                 => "No identity was provided by the OpenID identity server.",
+        'no_identity_server'          => "The provided URL doesn't declare its OpenID identity server.",
+        'no_return_to'                => "No return URL was provided by the OpenID identity server.",
+        'no_sig'                      => "No signature URL was provided by the OpenID identity server.",
+        'protocol_version_incorrect'  => "The provided URL uses the wrong protocol version",
+        'signature_mismatch'          => "The returned signature doesn't match.",
+        'time_bad_sig'                => "Bad time on signature.",
+        'time_expired'                => "Signature time expired.",
+        'time_in_future'              => "The OpenID identity server provided a time in the future.",
+        'url_fetch_err'               => "Error fetching the provided URL.",
     }->{$code};
 
     $self->{last_errcode} = $code;
@@ -906,7 +915,7 @@ Net::OpenID::Consumer - Library for consumers of OpenID identities
 
 =head1 VERSION
 
-version 1.030099_003
+version 1.030099_004
 
 =head1 SYNOPSIS
 
